@@ -38,6 +38,9 @@
 
 #include <packageurlinterceptor.h>
 
+namespace PlasmaQuick
+{
+
 QHash<QObject *, AppletQuickItem *> AppletQuickItemPrivate::s_rootObjects = QHash<QObject *, AppletQuickItem *>();
 
 AppletQuickItemPrivate::AppletQuickItemPrivate(Plasma::Applet *a, AppletQuickItem *item)
@@ -180,7 +183,7 @@ QObject *AppletQuickItemPrivate::createFullRepresentationItem()
         return fullRepresentationItem.data();
     }
 
-    if (fullRepresentation) {
+    if (fullRepresentation && fullRepresentation.data() != qmlObject->mainComponent()) {
         fullRepresentationItem = qmlObject->createObjectFromComponent(fullRepresentation.data(), QtQml::qmlContext(qmlObject->rootObject()));
     } else {
         fullRepresentation = qmlObject->mainComponent();
@@ -188,6 +191,11 @@ QObject *AppletQuickItemPrivate::createFullRepresentationItem()
         emit q->fullRepresentationChanged(fullRepresentation.data());
     }
 
+
+    if (!fullRepresentationItem) {
+        return 0;
+    }
+
     QQuickItem *graphicsObj = qobject_cast<QQuickItem *>(fullRepresentationItem.data());
     QObject::connect (graphicsObj, &QQuickItem::widthChanged, [=]() {
         fullRepresentationResizeTimer.start();
@@ -213,9 +221,11 @@ QObject *AppletQuickItemPrivate::createCompactRepresentationExpanderItem()
 
     compactRepresentationExpanderItem = qmlObject->createObjectFromComponent(compactRepresentationExpander.data(), QtQml::qmlContext(qmlObject->rootObject()));
 
+    if (!compactRepresentationExpanderItem) {
+        return 0;
+    }
 
     compactRepresentationExpanderItem.data()->setProperty("compactRepresentation", QVariant::fromValue(createCompactRepresentationItem()));
-    compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant::fromValue(createFullRepresentationItem()));
 
     return compactRepresentationExpanderItem.data();
 }
@@ -430,7 +440,7 @@ Plasma::Applet *AppletQuickItem::applet() const
 
 void AppletQuickItem::init()
 {
-    if (AppletQuickItemPrivate::s_rootObjects.contains(this)) {
+    if (AppletQuickItemPrivate::s_rootObjects.contains(d->qmlObject->engine())) {
         return;
     }
 
@@ -611,8 +621,10 @@ void AppletQuickItem::setExpanded(bool expanded)
         return;
     }
 
-    d->createFullRepresentationItem();
-    d->compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant::fromValue(d->createFullRepresentationItem()));
+    if (expanded) {
+        d->createFullRepresentationItem();
+        d->compactRepresentationExpanderItem.data()->setProperty("fullRepresentation", QVariant::fromValue(d->createFullRepresentationItem()));
+    }
 
     d->expanded = expanded;
     emit expandedChanged(expanded);
@@ -656,7 +668,7 @@ void AppletQuickItem::itemChange(ItemChange change, const ItemChangeData &value)
     QQuickItem::itemChange(change, value);
 }
 
-
+}
 
 #include "moc_appletquickitem.cpp"
 
